@@ -5,17 +5,19 @@ use warnings;
 use Carp;
 use namespace::autoclean;
 
-our $VERSION = 'v0.4.0'; # VERSION
+our $VERSION = 'v0.4.1'; # VERSION
 
 use Moose::Role;
 use MooseX::Types::Moose   qw( HashRef Str );
 use MooseX::Types::Varchar qw( Varchar );
 use MooseX::Types::URI     qw( Uri     );
+use MooseX::SetOnce 0.200001;
 
 with qw(
 	Business::CyberSource
 	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Request::Role::Credentials
+	Business::CyberSource::Role::MerchantReferenceCode
 );
 
 requires 'submit';
@@ -44,10 +46,11 @@ sub _build_request {
 		clientEnvironment     => $self->client_env,
 		clientLibrary         => $self->client_name,
 		clientLibraryVersion  => $self->client_version,
+		merchantReferenceCode => $self->reference_code,
 		%{ $self->_request_data },
 	);
 
-	$self->trace( $trace );
+	$self->_trace( $trace );
 
 	if ( $answer->{Fault} ) {
 		croak 'SOAP Fault: ' . $answer->{Fault}->{faultstring};
@@ -96,19 +99,12 @@ sub BUILD { ## no critic qw( Subroutines::RequireFinalReturn )
 	}
 }
 
-has reference_code => (
-	required => 1,
-	is       => 'ro',
-	isa      => Varchar[50],
-	trigger  => sub {
-		my $self = shift;
-		$self->_request_data->{merchantReferenceCode} = $self->reference_code;
-	},
-);
-
 has trace => (
-	is     => 'rw',
-	isa    => 'XML::Compile::SOAP::Trace',
+	is       => 'rw',
+	isa      => 'XML::Compile::SOAP::Trace',
+	traits   => [ 'SetOnce' ],
+	init_arg => undef,
+	writer   => '_trace',
 );
 
 has _request_data => (
@@ -133,7 +129,7 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version v0.4.0
+version v0.4.1
 
 =for Pod::Coverage BUILD
 
